.. pyroSAR documentation master file, created by
   sphinx-quickstart on Wed Mar 28 16:58:10 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

###################################
Welcome to pyroSAR's documentation!
###################################

General Topics
==============

.. toctree::
   :maxdepth: 1

   general/installation
   general/filenaming
   general/OSV
   general/DEM
   general/snap
   general/processing

API Documentation
=================

.. toctree::

   pyroSAR

About
=====

.. toctree::
   :maxdepth: 1

   about/projects
   about/changelog
   about/publications

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
